.. Places global toc into the sidebar

:globalsidebartoc: True

.. _tutorial_menu:


.. include:: ../includes/big_toc_css.rst
.. include:: ../tune_toc.rst

======================
scikit-learn Tutorials
======================

|

.. toctree::
   :maxdepth: 2

   basic/tutorial.rst
   statistical_inference/index.rst
   text_analytics/working_with_text_data.rst
   machine_learning_map/index
   ../presentations

|

.. note:: **Doctest Mode**

   The code-examples in the above tutorials are written in a
   *python-console* format. If you wish to easily execute these examples
   in **IPython**, use::

	%doctest_mode

   in the IPython-console. You can then simply copy and paste the examples
   directly into IPython without having to worry about removing the **>>>**
   manually.
